==> next-1.12.2.tgz: package/es/locale/zh-tw.js <==
export default {
    momentLocale: 'zh-tw',
    Timeline: {
        expand: '展開',
        fold: '收起'
    },
    Card: {
        expand: '展開',
        fold: '收起'
    },
    Calendar: {
        today: '今天',
        now: '此刻',
        ok: '確定',
        clear: '清除',
        month: '月',
        year: '年',
        prevYear: '上一年',
        nextYear: '下一年',
        prevMonth: '上个月',
        nextMonth: '下个月',
        prevDecade: '上十年',
        nextDecade: '后十年'
    },
    DatePicker: {
        placeholder: '請選擇日期',
        datetimePlaceholder: '請選擇日期和時間',
        monthPlaceholder: '請選擇月',
        yearPlaceholder: '請選擇年',
        now: '此刻',
        selectTime: '選擇時間',
        selectDate: '選擇日期',
        ok: '確定',
        clear: '清除',
        startPlaceholder: '起始日期',
        endPlaceholder: '結束日期',
        hour: '時',
        minute: '分',
        second: '秒'
    },
    Dialog: {
        close: '關閉',
        ok: '確認',
        cancel: '取消'
    },
    Pagination: {
        prev: '上一頁',
        next: '下一頁',
        goTo: '到第',
        page: '頁',
        go: '確定',
        total: '第{current}頁，共{total}頁',
        labelPrev: '上一頁，當前第{current}頁',
        labelNext: '下一頁，當前第{current}頁',
        pageSize: '每頁顯示：'
    },
    Input: {
        clear: '清除'
    },
    Select: {
        selectPlaceholder: '請選擇',
        autoCompletePlaceholder: '請輸入',
        notFoundContent: '無選項'
    },
    Table: {
        empty: '沒有數據',
        ok: '確認',
        reset: '重置',
        asc: '昇冪',
        desc: '降序',
        expanded: '已展開',
        folded: '已折疊',
        filter: '篩選',
        selectAll: '全選'
    },
    TimePicker: {
        placeholder: '請選擇時間',
        clear: '清除',
        hour: '時',
        minute: '分',
        second: '秒'
    },
    Transfer: {
        items: '項',
        item: '項',
        moveAll: '移動全部',
        searchPlaceholder: '請輸入'
    },
    Upload: {
        card: {
            cancel: '取消',
            addPhoto: '上傳圖片'
        },
        drag: {
            text: '點擊或者拖動文件到虛線框內上傳',
            hint: '支持 docx, xls, PDF, rar, zip, PNG, JPG 等類型的文件'
        }
    },
    Search: {
        buttonText: '檢索'
    }
};

==> next-1.13.3.tgz: package/es/locale/zh-tw.js <==
export default {
    momentLocale: 'zh-tw',
    Timeline: {
        expand: '展開',
        fold: '收起'
    },
    Balloon: {
        close: '關閉'
    },
    Card: {
        expand: '展開',
        fold: '收起'
    },
    Calendar: {
        today: '今天',
        now: '此刻',
        ok: '確定',
        clear: '清除',
        month: '月',
        year: '年',
        prevYear: '上一年',
        nextYear: '下一年',
        prevMonth: '上个月',
        nextMonth: '下个月',
        prevDecade: '上十年',
        nextDecade: '后十年',
        yearSelectAriaLabel: '選擇年份',
        monthSelectAriaLabel: '選擇月份'
    },
    DatePicker: {
        placeholder: '請選擇日期',
        datetimePlaceholder: '請選擇日期和時間',
        monthPlaceholder: '請選擇月',
        yearPlaceholder: '請選擇年',
        now: '此刻',
        selectTime: '選擇時間',
        selectDate: '選擇日期',
        ok: '確定',
        clear: '清除',
        startPlaceholder: '起始日期',
        endPlaceholder: '結束日期',
        hour: '時',
        minute: '分',
        second: '秒'
    },
    Dialog: {
        close: '關閉',
        ok: '確認',
        cancel: '取消'
    },
    Message: {
        closeAriaLabel: '關閉'
    },
    Pagination: {
        prev: '上一頁',
        next: '下一頁',
        goTo: '到第',
        page: '頁',
        go: '確定',
        total: '第{current}頁，共{total}頁',
        labelPrev: '上一頁，當前第{current}頁',
        labelNext: '下一頁，當前第{current}頁',
        inputAriaLabel: '請輸入跳轉到第幾頁',
        selectAriaLabel: '請選擇每頁顯示幾條',
        pageSize: '每頁顯示：'
    },
    Input: {
        clear: '清除'
    },
    Select: {
        selectPlaceholder: '請選擇',
        autoCompletePlaceholder: '請輸入',
        notFoundContent: '無選項'
    },
    Table: {
        empty: '沒有數據',
        ok: '確認',
        reset: '重置',
        asc: '昇冪',
        desc: '降序',
        expanded: '已展開',
        folded: '已折疊',
        filter: '篩選',
        selectAll: '全選'
    },
    TimePicker: {
        placeholder: '請選擇時間',
        clear: '清除',
        hour: '時',
        minute: '分',
        second: '秒'
    },
    Transfer: {
        items: '項',
        item: '項',
        moveAll: '移動全部',
        searchPlaceholder: '請輸入',
        moveToLeft: '撤銷選中元素',
        moveToRight: '提交選中元素'
    },
    Upload: {
        card: {
            cancel: '取消',
            addPhoto: '上傳圖片'
        },
        drag: {
            text: '點擊或者拖動文件到虛線框內上傳',
            hint: '支持 docx, xls, PDF, rar, zip, PNG, JPG 等類型的文件'
        }
    },
    Search: {
        buttonText: '檢索'
    },
    Tag: {
        delete: '删除'
    }
};
